package com.mcsnowflake.worktimer

import android.app.NotificationManager
import android.content.Context
import android.media.AudioManager
import androidx.datastore.core.DataStore
import androidx.datastore.preferences.core.Preferences
import com.mcsnowflake.worktimer.notifications.DoNotDisturbModeHandler
import com.mcsnowflake.worktimer.notifications.NotificationHandler
import com.mcsnowflake.worktimer.service.TimerActionEmitter
import com.mcsnowflake.worktimer.service.WorkTimer
import com.mcsnowflake.worktimer.ui.DashBoardViewModel
import com.mcsnowflake.worktimer.ui.settings.SettingsViewModel
import com.mcsnowflake.worktimer.ui.setupView.SetupViewModel
import com.mcsnowflake.worktimer.ui.shared.AppBarViewModel
import kotlinx.coroutines.CoroutineScope
import org.koin.android.ext.koin.androidContext
import org.koin.androidx.viewmodel.dsl.viewModel
import org.koin.dsl.module

fun getModule(dataStore: DataStore<Preferences>) = module {

    single { dataStore }
    factory { (scope: CoroutineScope) -> WorkTimer(scope, get()) }
    single { androidContext().getSystemService(Context.NOTIFICATION_SERVICE) as NotificationManager }
    single { androidContext().getSystemService(Context.AUDIO_SERVICE) as AudioManager }
    single { NotificationHandler(androidContext(), get(), get()) }
    single { DoNotDisturbModeHandler(get()) }
    single { TimerActionEmitter(androidContext()) }

    viewModel { DashBoardViewModel(get()) }
    viewModel { SettingsViewModel(get()) }
    viewModel { SetupViewModel(get()) }
    viewModel { AppBarViewModel() }
}
